@@ -8,7 +8,7 @@ use base qw/Net::Server::Coro Class::Accessor/;
 use UNIVERSAL::require;
 use Coro;
 
-our $VERSION = '1.30';
+our $VERSION = '1.31';
 
 =head1 NAME
 
@@ -422,48 +422,52 @@ characters denote array references or relations.
    |                    Server                    |
    |                                              |
    +1-----2---------------------------------------+
-    #     '      ^         ^            ^        ^
-    #     '      |         |            |        |
+    #     |      ^         ^            ^        ^
+    #     |      |         |            |        |
     #     v      |         |            |        |
     #   +--------1-------+ |     +------1------+ |
     ###>|   Connection   |<------2   Command   | |
     #   +--4-----3------2+ |     +-------------+ |
-  /-#------/     |      \--------------\         |
+  ,-#------'     |      `--------------.         |
   | #            v         |           v         |
   | #   +----------------+ |     +-------------+ |
   | #   |     Model      2------>|    Auth     | |
   | #   +--------1-------+ |     +-------------+ |
-  | #            \---------------------------------\
+  | #            `---------------------------------.
   | #                      |                     | |
-  | #                  /---/                 /---/ |
+  | #                  ,---'                 ,---' |
   | #   +--------------1-+       +-----------1-+   |
   | ###>|   Connection   |<------2   Command   |   |
   |     +--4-5---3------2+       +-------------+   |
-  | /------/ *   |      \--------------\           |
+  | ,------' *   |      `--------------.           |
   | | ********   v                     v           |
   | | * +----------------+       +-------------+   |
   | | * |     Model      2------>|    Auth     |   |
   | | * +--------1-------+       +-------------+   |
   | | *          |                                 |
-  | | *          |  /------------------------------/
+  | | *          |  ,------------------------------'
   | | *          |  |           ^ SERVER
-  |.|.*..........|..|................................
+ .|.|.*..........|..|................................
   | | *          |  |           v MODEL
   | | *          v  v
-  | \-*---->+-------------+<------------\
-  \---*---->|   Mailbox   |<----------\ |
-      *     +-1------2-3--+<----\     | |
+  | '-*---->+-------------+<------------.
+  '---*---->|   Mailbox   |<----------. |
+      *     +-1------2-3--+<----.     | |
       *       @   ^  $ %        |     | |
-      *       @   |  $$%$>+-----1---+ | |
+      *       @   |  $$$$>+-----1---+ | |
+      *       @   |  $ %  |         | | |
       *       @   |  $ %%>| Message | | |
-      ********@***|****%*>+---------+ | |
+      *       @   |  $ %  |         | | |
+      ********@***|******>+---------+ | |
       *       @   |  $ %              | |
-      *       @   |  $$%$>+---------+ | |
-      *       @   |    %%>| Message 1-/ |
+      *       @   |  $$$$>+---------+ | |
+      *       @   |    %  |         | | |
+      *       @   |    %%>| Message 1-' |
+      *       @   |       |         |   |
       ********@***|******>+---------+   |
       *       @   |                     |
       *       @   |       +---------+   |
-      *       @   |       | Message 1---/
+      *       @   |       | Message 1---'
       ********@***|******>+---------+
               @   |
               @  +4----------+
